@@ -1,5 +1,6 @@
 import os 
 import sys
+import time
 class bcolors:
     HEADER = '\033[95m'
     OKBLUE = '\033[94m'
@@ -20,6 +21,7 @@ def filestructure():
         # Checks if /tmp/fruits is created
         if os.path.getsize(FILETOWORK) <= 0:
             print(bcolors.FAIL + FILETOWORK + " " + "seems to be empty" + bcolors.ENDC  )
+        time.sleep(0.5)
 
     except FileNotFoundError:
         print(bcolors.FAIL +  FILETOWORK + " is not created"+ bcolors.ENDC)
@@ -34,6 +36,7 @@ def filestructure():
             print(bcolors.FAIL +  "Something went wrong please try again" + bcolors.ENDC)
     except FileNotFoundError:
         print(bcolors.FAIL +  FILETOWORK + " is not created"+ bcolors.ENDC)
+    time.sleep(0.5)
 
     try:
         FILETOWORK="/tmp/top10"
@@ -47,6 +50,7 @@ def filestructure():
             print(bcolors.FAIL +  FILETOWORK + " has not been created or has %d lines" % num_lines + bcolors.ENDC)
     except FileNotFoundError:
         print(bcolors.FAIL +  FILETOWORK + " is not created"+ bcolors.ENDC)
+    time.sleep(0.5)
 
     try:
         FILETOWORK="/tmp/bottom10"
@@ -60,6 +64,7 @@ def filestructure():
             print(bcolors.FAIL +  FILETOWORK + " has not been created or has %d lines" % num_lines + bcolors.ENDC)
     except FileNotFoundError:
         print(bcolors.FAIL +  FILETOWORK + " is not created"+ bcolors.ENDC)
+    time.sleep(0.5)
 
     try:
         FILETOWORK="/tmp/sorted_fruits"
@@ -72,6 +77,7 @@ def filestructure():
             print(bcolors.FAIL +  "Something went wrong please try again" + bcolors.ENDC)
     except FileNotFoundError:
         print(bcolors.FAIL +  FILETOWORK + " is not created"+ bcolors.ENDC)
+    time.sleep(0.5)
 
     try:
         FILETOWORK="/tmp/counted_services"
@@ -94,6 +100,7 @@ def filestructure():
     except FileNotFoundError:
         print(bcolors.FAIL +  FILETOWORK + " is not created"+ bcolors.ENDC)
         sys.exit(1)
+    time.sleep(0.5)
 
  # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
  
